[gedit/eggplugins: 1/6] Move Gedit plugin stuff into /libplugins
- From: Steve Frécinaux <sfre src gnome org>
- To: svn-commits-list gnome org
- Cc:
- Subject: [gedit/eggplugins: 1/6] Move Gedit plugin stuff into /libplugins
- Date: Fri, 9 Oct 2009 18:04:04 +0000 (UTC)
commit e240072d7dabb53f234e331d348d032f50db4e49
Author: Steve Frécinaux <code istique net>
Date: Wed Oct 7 13:33:41 2009 +0200
Move Gedit plugin stuff into /libplugins
Makefile.am | 2 +-
configure.ac | 1 +
gedit/Makefile.am | 12 +-------
gedit/gedit-plugin-manager.c | 4 +-
gedit/gedit-prefs-manager-app.c | 2 +-
gedit/gedit-session.c | 2 +-
gedit/gedit-window.c | 2 +-
gedit/gedit.c | 2 +-
libplugins/Makefile.am | 30 +++++++++++++++++++
{gedit => libplugins}/gedit-object-module.c | 2 +-
{gedit => libplugins}/gedit-object-module.h | 0
{gedit => libplugins}/gedit-plugin-info-priv.h | 0
{gedit => libplugins}/gedit-plugin-info.c | 2 +-
{gedit => libplugins}/gedit-plugin-info.h | 0
{gedit => libplugins}/gedit-plugin-loader.c | 0
{gedit => libplugins}/gedit-plugin-loader.h | 4 +-
{gedit => libplugins}/gedit-plugin.c | 22 +++++++-------
{gedit => libplugins}/gedit-plugin.h | 14 ++++----
{gedit => libplugins}/gedit-plugins-engine.c | 31 ++++++++++---------
{gedit => libplugins}/gedit-plugins-engine.h | 10 +++---
plugin-loaders/c/gedit-plugin-loader-c.c | 2 +-
plugin-loaders/c/gedit-plugin-loader-c.h | 2 +-
plugin-loaders/python/bindings/gedit.override | 2 +-
.../python/bindings/geditplugin.override | 2 +-
plugin-loaders/python/gedit-plugin-loader-python.c | 2 +-
plugin-loaders/python/gedit-plugin-loader-python.h | 2 +-
plugin-loaders/python/gedit-plugin-python.c | 3 +-
plugin-loaders/python/gedit-plugin-python.h | 2 +-
28 files changed, 91 insertions(+), 68 deletions(-)
---
diff --git a/Makefile.am b/Makefile.am
index 9d771ea..a06488b 100644
--- a/Makefile.am
+++ b/Makefile.am
@@ -1,7 +1,7 @@
## Process this file with automake to produce Makefile.in
ACLOCAL_AMFLAGS = -I m4
-SUBDIRS = gedit pixmaps po help data plugin-loaders plugins docs win32
+SUBDIRS = libplugins gedit pixmaps po help data plugin-loaders docs win32
distuninstallcheck_listfiles = find . -type f -print | grep -v scrollkeeper
diff --git a/configure.ac b/configure.ac
index 013a721..49df647 100644
--- a/configure.ac
+++ b/configure.ac
@@ -448,6 +448,7 @@ gedit/dialogs/Makefile
gedit/smclient/Makefile
gedit/Makefile
help/Makefile
+libplugins/Makefile
pixmaps/Makefile
plugin-loaders/Makefile
plugin-loaders/c/Makefile
diff --git a/gedit/Makefile.am b/gedit/Makefile.am
index 35ea707..dc19385 100644
--- a/gedit/Makefile.am
+++ b/gedit/Makefile.am
@@ -33,6 +33,7 @@ endif
libgedit_la_LDFLAGS = -export-dynamic -no-undefined -export-symbols-regex "^[[^_]].*"
libgedit_la_LIBADD = \
+ ../libplugins/libplugins.la \
dialogs/libdialogs.la \
smclient/libeggsmclient.la
@@ -55,11 +56,7 @@ endif
NOINST_H_FILES = \
gedit-language-manager.h \
gedit-style-scheme-manager.h \
- gedit-plugin-info.h \
- gedit-plugin-info-priv.h \
gedit-plugin-manager.h \
- gedit-plugins-engine.h \
- gedit-object-module.h \
gedit-ui.h \
gedit-window-private.h \
gedit-documents-panel.h \
@@ -94,8 +91,6 @@ INST_H_FILES = \
gedit-metadata-manager.h \
gedit-notebook.h \
gedit-panel.h \
- gedit-plugin.h \
- gedit-plugin-loader.h \
gedit-prefs-manager-app.h \
gedit-prefs-manager.h \
gedit-progress-message-area.h \
@@ -151,14 +146,9 @@ libgedit_la_SOURCES = \
gedit-message-type.c \
gedit-message.c \
gedit-metadata-manager.c \
- gedit-object-module.c \
gedit-notebook.c \
gedit-panel.c \
- gedit-plugin-info.c \
- gedit-plugin.c \
- gedit-plugin-loader.c \
gedit-plugin-manager.c \
- gedit-plugins-engine.c \
gedit-prefs-manager-app.c \
gedit-prefs-manager.c \
gedit-prefs-manager-private.h \
diff --git a/gedit/gedit-plugin-manager.c b/gedit/gedit-plugin-manager.c
index 95b02df..30941ad 100644
--- a/gedit/gedit-plugin-manager.c
+++ b/gedit/gedit-plugin-manager.c
@@ -39,8 +39,8 @@
#include "gedit-plugin-manager.h"
#include "gedit-utils.h"
-#include "gedit-plugins-engine.h"
-#include "gedit-plugin.h"
+#include <libplugins/gedit-plugins-engine.h>
+#include <libplugins/gedit-plugin.h>
#include "gedit-debug.h"
enum
diff --git a/gedit/gedit-prefs-manager-app.c b/gedit/gedit-prefs-manager-app.c
index 802cd8a..355dc11 100644
--- a/gedit/gedit-prefs-manager-app.c
+++ b/gedit/gedit-prefs-manager-app.c
@@ -43,7 +43,7 @@
#include "gedit-view.h"
#include "gedit-window.h"
#include "gedit-window-private.h"
-#include "gedit-plugins-engine.h"
+#include <libplugins/gedit-plugins-engine.h>
#include "gedit-style-scheme-manager.h"
#include "gedit-dirs.h"
diff --git a/gedit/gedit-session.c b/gedit/gedit-session.c
index 7468664..5c2fed5 100644
--- a/gedit/gedit-session.c
+++ b/gedit/gedit-session.c
@@ -45,7 +45,7 @@
#include "gedit-session.h"
#include "gedit-debug.h"
-#include "gedit-plugins-engine.h"
+#include <libplugins/gedit-plugins-engine.h>
#include "gedit-prefs-manager-app.h"
#include "gedit-metadata-manager.h"
#include "gedit-window.h"
diff --git a/gedit/gedit-window.c b/gedit/gedit-window.c
index 680393c..d571409 100644
--- a/gedit/gedit-window.c
+++ b/gedit/gedit-window.c
@@ -52,7 +52,7 @@
#include "gedit-prefs-manager-app.h"
#include "gedit-panel.h"
#include "gedit-documents-panel.h"
-#include "gedit-plugins-engine.h"
+#include <libplugins/gedit-plugins-engine.h>
#include "gedit-enum-types.h"
#include "gedit-dirs.h"
#include "gedit-status-combo-box.h"
diff --git a/gedit/gedit.c b/gedit/gedit.c
index 03a1705..951194e 100644
--- a/gedit/gedit.c
+++ b/gedit/gedit.c
@@ -51,7 +51,7 @@
#include "gedit-dirs.h"
#include "gedit-encodings.h"
#include "gedit-metadata-manager.h"
-#include "gedit-plugins-engine.h"
+#include <libplugins/gedit-plugins-engine.h>
#include "gedit-prefs-manager-app.h"
#include "gedit-session.h"
#include "gedit-utils.h"
diff --git a/libplugins/Makefile.am b/libplugins/Makefile.am
new file mode 100644
index 0000000..f08db3c
--- /dev/null
+++ b/libplugins/Makefile.am
@@ -0,0 +1,30 @@
+noinst_LTLIBRARIES = libplugins.la
+
+INCLUDES = \
+ -I$(top_srcdir) \
+ -I$(srcdir) \
+ -I$(srcdir)/smclient \
+ $(GEDIT_CFLAGS) \
+ $(WARN_CFLAGS) \
+ $(DISABLE_DEPRECATED_CFLAGS)
+
+libplugins_la_LDFLAGS = -export-dynamic -no-undefined -export-symbols-regex "^[[^_]].*"
+libplugins_la_LIBADD = $(GEDIT_LIBS)
+
+NOINST_H_FILES = \
+ gedit-plugin.h \
+ gedit-plugin-info.h \
+ gedit-plugin-info-priv.h \
+ gedit-plugins-engine.h \
+ gedit-plugin-loader.h \
+ gedit-object-module.h
+
+libplugins_la_SOURCES = \
+ gedit-plugin.c \
+ gedit-plugin-info.c \
+ gedit-plugins-engine.c \
+ gedit-plugin-loader.c \
+ gedit-object-module.c \
+ $(NOINST_H_FILES)
+
+-include $(top_srcdir)/git.mk
diff --git a/gedit/gedit-object-module.c b/libplugins/gedit-object-module.c
similarity index 99%
rename from gedit/gedit-object-module.c
rename to libplugins/gedit-object-module.c
index 3c6f09c..7ae7686 100644
--- a/gedit/gedit-object-module.c
+++ b/libplugins/gedit-object-module.c
@@ -40,7 +40,7 @@
#include "config.h"
#include "gedit-object-module.h"
-#include "gedit-debug.h"
+#include <gedit/gedit-debug.h>
typedef GType (*GeditObjectModuleRegisterFunc) (GTypeModule *);
diff --git a/gedit/gedit-object-module.h b/libplugins/gedit-object-module.h
similarity index 100%
rename from gedit/gedit-object-module.h
rename to libplugins/gedit-object-module.h
diff --git a/gedit/gedit-plugin-info-priv.h b/libplugins/gedit-plugin-info-priv.h
similarity index 100%
rename from gedit/gedit-plugin-info-priv.h
rename to libplugins/gedit-plugin-info-priv.h
diff --git a/gedit/gedit-plugin-info.c b/libplugins/gedit-plugin-info.c
similarity index 99%
rename from gedit/gedit-plugin-info.c
rename to libplugins/gedit-plugin-info.c
index 31411c4..0aa28c3 100644
--- a/gedit/gedit-plugin-info.c
+++ b/libplugins/gedit-plugin-info.c
@@ -39,7 +39,7 @@
#include "gedit-plugin-info.h"
#include "gedit-plugin-info-priv.h"
-#include "gedit-debug.h"
+#include <gedit/gedit-debug.h>
#include "gedit-plugin.h"
void
diff --git a/gedit/gedit-plugin-info.h b/libplugins/gedit-plugin-info.h
similarity index 100%
rename from gedit/gedit-plugin-info.h
rename to libplugins/gedit-plugin-info.h
diff --git a/gedit/gedit-plugin-loader.c b/libplugins/gedit-plugin-loader.c
similarity index 100%
rename from gedit/gedit-plugin-loader.c
rename to libplugins/gedit-plugin-loader.c
diff --git a/gedit/gedit-plugin-loader.h b/libplugins/gedit-plugin-loader.h
similarity index 98%
rename from gedit/gedit-plugin-loader.h
rename to libplugins/gedit-plugin-loader.h
index a064e5e..db0ed8c 100644
--- a/gedit/gedit-plugin-loader.h
+++ b/libplugins/gedit-plugin-loader.h
@@ -24,8 +24,8 @@
#define __GEDIT_PLUGIN_LOADER_H__
#include <glib-object.h>
-#include <gedit/gedit-plugin.h>
-#include <gedit/gedit-plugin-info.h>
+#include "gedit-plugin.h"
+#include "gedit-plugin-info.h"
G_BEGIN_DECLS
diff --git a/gedit/gedit-plugin.c b/libplugins/gedit-plugin.c
similarity index 95%
rename from gedit/gedit-plugin.c
rename to libplugins/gedit-plugin.c
index 2b00e3f..29ae67a 100644
--- a/gedit/gedit-plugin.c
+++ b/libplugins/gedit-plugin.c
@@ -33,7 +33,7 @@
#endif
#include "gedit-plugin.h"
-#include "gedit-dirs.h"
+#include <gedit/gedit-dirs.h>
/* properties */
enum {
@@ -56,7 +56,7 @@ struct _GeditPluginPrivate
G_DEFINE_TYPE(GeditPlugin, gedit_plugin, G_TYPE_OBJECT)
static void
-dummy (GeditPlugin *plugin, GeditWindow *window)
+dummy (GeditPlugin *plugin, GtkWindow *window)
{
/* Empty */
}
@@ -252,16 +252,16 @@ gedit_plugin_get_data_dir (GeditPlugin *plugin)
/**
* gedit_plugin_activate:
* @plugin: a #GeditPlugin
- * @window: a #GeditWindow
+ * @window: a #GtkWindow
*
* Activates the plugin.
*/
void
gedit_plugin_activate (GeditPlugin *plugin,
- GeditWindow *window)
+ GtkWindow *window)
{
g_return_if_fail (GEDIT_IS_PLUGIN (plugin));
- g_return_if_fail (GEDIT_IS_WINDOW (window));
+ g_return_if_fail (GTK_IS_WINDOW (window));
GEDIT_PLUGIN_GET_CLASS (plugin)->activate (plugin, window);
}
@@ -269,16 +269,16 @@ gedit_plugin_activate (GeditPlugin *plugin,
/**
* gedit_plugin_deactivate:
* @plugin: a #GeditPlugin
- * @window: a #GeditWindow
+ * @window: a #GtkWindow
*
* Deactivates the plugin.
*/
void
gedit_plugin_deactivate (GeditPlugin *plugin,
- GeditWindow *window)
+ GtkWindow *window)
{
g_return_if_fail (GEDIT_IS_PLUGIN (plugin));
- g_return_if_fail (GEDIT_IS_WINDOW (window));
+ g_return_if_fail (GTK_IS_WINDOW (window));
GEDIT_PLUGIN_GET_CLASS (plugin)->deactivate (plugin, window);
}
@@ -286,17 +286,17 @@ gedit_plugin_deactivate (GeditPlugin *plugin,
/**
* gedit_plugin_update_ui:
* @plugin: a #GeditPlugin
- * @window: a #GeditWindow
+ * @window: a #GtkWindow
*
* Triggers an update of the user interface to take into account state changes
* caused by the plugin.
*/
void
gedit_plugin_update_ui (GeditPlugin *plugin,
- GeditWindow *window)
+ GtkWindow *window)
{
g_return_if_fail (GEDIT_IS_PLUGIN (plugin));
- g_return_if_fail (GEDIT_IS_WINDOW (window));
+ g_return_if_fail (GTK_IS_WINDOW (window));
GEDIT_PLUGIN_GET_CLASS (plugin)->update_ui (plugin, window);
}
diff --git a/gedit/gedit-plugin.h b/libplugins/gedit-plugin.h
similarity index 97%
rename from gedit/gedit-plugin.h
rename to libplugins/gedit-plugin.h
index 8cf41d8..299cf47 100644
--- a/gedit/gedit-plugin.h
+++ b/libplugins/gedit-plugin.h
@@ -33,7 +33,7 @@
#include <glib-object.h>
-#include <gedit/gedit-window.h>
+#include <gtk/gtk.h>
#include <gedit/gedit-debug.h>
/* TODO: add a .h file that includes all the .h files normally needed to
@@ -73,12 +73,12 @@ struct _GeditPluginClass
/* Virtual public methods */
void (*activate) (GeditPlugin *plugin,
- GeditWindow *window);
+ GtkWindow *window);
void (*deactivate) (GeditPlugin *plugin,
- GeditWindow *window);
+ GtkWindow *window);
void (*update_ui) (GeditPlugin *plugin,
- GeditWindow *window);
+ GtkWindow *window);
GtkWidget *(*create_configure_dialog)
(GeditPlugin *plugin);
@@ -104,12 +104,12 @@ gchar *gedit_plugin_get_install_dir (GeditPlugin *plugin);
gchar *gedit_plugin_get_data_dir (GeditPlugin *plugin);
void gedit_plugin_activate (GeditPlugin *plugin,
- GeditWindow *window);
+ GtkWindow *window);
void gedit_plugin_deactivate (GeditPlugin *plugin,
- GeditWindow *window);
+ GtkWindow *window);
void gedit_plugin_update_ui (GeditPlugin *plugin,
- GeditWindow *window);
+ GtkWindow *window);
gboolean gedit_plugin_is_configurable (GeditPlugin *plugin);
GtkWidget *gedit_plugin_create_configure_dialog
diff --git a/gedit/gedit-plugins-engine.c b/libplugins/gedit-plugins-engine.c
similarity index 96%
rename from gedit/gedit-plugins-engine.c
rename to libplugins/gedit-plugins-engine.c
index 3f020d3..5e99283 100644
--- a/gedit/gedit-plugins-engine.c
+++ b/libplugins/gedit-plugins-engine.c
@@ -38,13 +38,14 @@
#include "gedit-plugins-engine.h"
#include "gedit-plugin-info-priv.h"
-#include "gedit-plugin.h"
-#include "gedit-debug.h"
-#include "gedit-app.h"
-#include "gedit-prefs-manager.h"
#include "gedit-plugin-loader.h"
#include "gedit-object-module.h"
-#include "gedit-dirs.h"
+#include "gedit-plugin.h"
+#include <gedit/gedit-debug.h>
+#include <gedit/gedit-app.h>
+#include <gedit/gedit-window.h>
+#include <gedit/gedit-prefs-manager.h>
+#include <gedit/gedit-dirs.h>
#define GEDIT_PLUGINS_ENGINE_BASE_KEY "/apps/gedit-2/plugins"
#define GEDIT_PLUGINS_ENGINE_KEY GEDIT_PLUGINS_ENGINE_BASE_KEY "/active-plugins"
@@ -600,7 +601,7 @@ gedit_plugins_engine_activate_plugin_real (GeditPluginsEngine *engine,
wins != NULL;
wins = wins->next)
{
- gedit_plugin_activate (info->plugin, GEDIT_WINDOW (wins->data));
+ gedit_plugin_activate (info->plugin, GTK_WINDOW (wins->data));
}
}
@@ -628,7 +629,7 @@ gedit_plugins_engine_activate_plugin (GeditPluginsEngine *engine,
static void
call_plugin_deactivate (GeditPlugin *plugin,
- GeditWindow *window)
+ GtkWindow *window)
{
gedit_plugin_deactivate (plugin, window);
@@ -636,7 +637,7 @@ call_plugin_deactivate (GeditPlugin *plugin,
with expected static strings in the type module (when unloaded the
strings don't exist anymore, and ui manager updates in an idle
func) */
- gtk_ui_manager_ensure_update (gedit_window_get_ui_manager (window));
+ gtk_ui_manager_ensure_update (gedit_window_get_ui_manager (GEDIT_WINDOW (window)));
}
static void
@@ -654,7 +655,7 @@ gedit_plugins_engine_deactivate_plugin_real (GeditPluginsEngine *engine,
wins != NULL;
wins = wins->next)
{
- call_plugin_deactivate (info->plugin, GEDIT_WINDOW (wins->data));
+ call_plugin_deactivate (info->plugin, GTK_WINDOW (wins->data));
}
/* first unref the plugin (the loader still has one) */
@@ -689,7 +690,7 @@ gedit_plugins_engine_deactivate_plugin (GeditPluginsEngine *engine,
void
gedit_plugins_engine_activate_plugins (GeditPluginsEngine *engine,
- GeditWindow *window)
+ GtkWindow *window)
{
GSList *active_plugins = NULL;
GList *pl;
@@ -697,7 +698,7 @@ gedit_plugins_engine_activate_plugins (GeditPluginsEngine *engine,
gedit_debug (DEBUG_PLUGINS);
g_return_if_fail (GEDIT_IS_PLUGINS_ENGINE (engine));
- g_return_if_fail (GEDIT_IS_WINDOW (window));
+ g_return_if_fail (GTK_IS_WINDOW (window));
/* the first time, we get the 'active' plugins from gconf */
if (engine->priv->activate_from_prefs)
@@ -740,14 +741,14 @@ gedit_plugins_engine_activate_plugins (GeditPluginsEngine *engine,
void
gedit_plugins_engine_deactivate_plugins (GeditPluginsEngine *engine,
- GeditWindow *window)
+ GtkWindow *window)
{
GList *pl;
gedit_debug (DEBUG_PLUGINS);
g_return_if_fail (GEDIT_IS_PLUGINS_ENGINE (engine));
- g_return_if_fail (GEDIT_IS_WINDOW (window));
+ g_return_if_fail (GTK_IS_WINDOW (window));
for (pl = engine->priv->plugin_list; pl; pl = pl->next)
{
@@ -766,14 +767,14 @@ gedit_plugins_engine_deactivate_plugins (GeditPluginsEngine *engine,
void
gedit_plugins_engine_update_plugins_ui (GeditPluginsEngine *engine,
- GeditWindow *window)
+ GtkWindow *window)
{
GList *pl;
gedit_debug (DEBUG_PLUGINS);
g_return_if_fail (GEDIT_IS_PLUGINS_ENGINE (engine));
- g_return_if_fail (GEDIT_IS_WINDOW (window));
+ g_return_if_fail (GTK_IS_WINDOW (window));
/* call update_ui for all active plugins */
for (pl = engine->priv->plugin_list; pl; pl = pl->next)
diff --git a/plugin-loaders/c/gedit-plugin-loader-c.c b/plugin-loaders/c/gedit-plugin-loader-c.c
index 37b3d05..ba2127c 100644
--- a/plugin-loaders/c/gedit-plugin-loader-c.c
+++ b/plugin-loaders/c/gedit-plugin-loader-c.c
@@ -21,7 +21,7 @@
*/
#include "gedit-plugin-loader-c.h"
-#include <gedit/gedit-object-module.h>
+#include <libplugins/gedit-object-module.h>
#define GEDIT_PLUGIN_LOADER_C_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GEDIT_TYPE_PLUGIN_LOADER_C, GeditPluginLoaderCPrivate))
diff --git a/plugin-loaders/c/gedit-plugin-loader-c.h b/plugin-loaders/c/gedit-plugin-loader-c.h
index 7042054..851f2a5 100644
--- a/plugin-loaders/c/gedit-plugin-loader-c.h
+++ b/plugin-loaders/c/gedit-plugin-loader-c.h
@@ -23,7 +23,7 @@
#ifndef __GEDIT_PLUGIN_LOADER_C_H__
#define __GEDIT_PLUGIN_LOADER_C_H__
-#include <gedit/gedit-plugin-loader.h>
+#include <libplugins/gedit-plugin-loader.h>
G_BEGIN_DECLS
diff --git a/plugin-loaders/python/bindings/gedit.override b/plugin-loaders/python/bindings/gedit.override
index afc67ca..04ad8d3 100644
--- a/plugin-loaders/python/bindings/gedit.override
+++ b/plugin-loaders/python/bindings/gedit.override
@@ -4,7 +4,7 @@ headers
#include <pygtk/pygtk.h>
#include <gedit/gedit-language-manager.h>
-#include <gedit/gedit-plugin.h>
+#include <libplugins/gedit-plugin.h>
#include <gedit/gedit-app.h>
#include <gedit/gedit-encodings.h>
#include <gedit/gedit-enum-types.h>
diff --git a/plugin-loaders/python/bindings/geditplugin.override b/plugin-loaders/python/bindings/geditplugin.override
index 178ea99..f5e07d5 100644
--- a/plugin-loaders/python/bindings/geditplugin.override
+++ b/plugin-loaders/python/bindings/geditplugin.override
@@ -1,6 +1,6 @@
%%
headers
-#include <gedit/gedit-plugin.h>
+#include <libplugins/gedit-plugin.h>
#include <gedit/gedit-window.h>
%%
override gedit_plugin_activate kwargs
diff --git a/plugin-loaders/python/gedit-plugin-loader-python.c b/plugin-loaders/python/gedit-plugin-loader-python.c
index 0b718e4..4d411aa 100644
--- a/plugin-loaders/python/gedit-plugin-loader-python.c
+++ b/plugin-loaders/python/gedit-plugin-loader-python.c
@@ -22,7 +22,7 @@
#include "gedit-plugin-loader-python.h"
#include "gedit-plugin-python.h"
-#include <gedit/gedit-object-module.h>
+#include <libplugins/gedit-object-module.h>
#define NO_IMPORT_PYGOBJECT
#define NO_IMPORT_PYGTK
diff --git a/plugin-loaders/python/gedit-plugin-loader-python.h b/plugin-loaders/python/gedit-plugin-loader-python.h
index 35ae241..32df471 100644
--- a/plugin-loaders/python/gedit-plugin-loader-python.h
+++ b/plugin-loaders/python/gedit-plugin-loader-python.h
@@ -23,7 +23,7 @@
#ifndef __GEDIT_PLUGIN_LOADER_PYTHON_H__
#define __GEDIT_PLUGIN_LOADER_PYTHON_H__
-#include <gedit/gedit-plugin-loader.h>
+#include <libplugins/gedit-plugin-loader.h>
G_BEGIN_DECLS
diff --git a/plugin-loaders/python/gedit-plugin-python.c b/plugin-loaders/python/gedit-plugin-python.c
index 0573828..f85c689 100644
--- a/plugin-loaders/python/gedit-plugin-python.c
+++ b/plugin-loaders/python/gedit-plugin-python.c
@@ -25,8 +25,9 @@
#include "gedit-plugin-python.h"
-#include <gedit/gedit-plugin.h>
+#include <libplugins/gedit-plugin.h>
#include <gedit/gedit-debug.h>
+#include <gedit/gedit-window.h>
#include <pygobject.h>
#include <string.h>
diff --git a/plugin-loaders/python/gedit-plugin-python.h b/plugin-loaders/python/gedit-plugin-python.h
index e67584b..d8b2566 100644
--- a/plugin-loaders/python/gedit-plugin-python.h
+++ b/plugin-loaders/python/gedit-plugin-python.h
@@ -29,7 +29,7 @@
#include <glib-object.h>
#include <pygobject.h>
-#include <gedit/gedit-plugin.h>
+#include <libplugins/gedit-plugin.h>
G_BEGIN_DECLS
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
diff --git a/gedit/gedit-plugins-engine.h b/libplugins/gedit-plugins-engine.h
similarity index 94%
rename from gedit/gedit-plugins-engine.h
rename to libplugins/gedit-plugins-engine.h
index 975c1e9..d4ed37a 100644
--- a/gedit/gedit-plugins-engine.h
+++ b/libplugins/gedit-plugins-engine.h
@@ -32,7 +32,7 @@
#define __GEDIT_PLUGINS_ENGINE_H__
#include <glib.h>
-#include "gedit-window.h"
+#include <gtk/gtk.h>
#include "gedit-plugin-info.h"
#include "gedit-plugin.h"
@@ -88,13 +88,13 @@ void gedit_plugins_engine_configure_plugin (GeditPluginsEngine *engine,
GeditPluginInfo *info,
GtkWindow *parent);
/* plugin activation/deactivation per window, private to GeditWindow */
void gedit_plugins_engine_activate_plugins (GeditPluginsEngine *engine,
- GeditWindow *window);
+ GtkWindow *window);
void gedit_plugins_engine_deactivate_plugins (GeditPluginsEngine *engine,
- GeditWindow *window);
+ GtkWindow *window);
void gedit_plugins_engine_update_plugins_ui (GeditPluginsEngine *engine,
- GeditWindow *window);
+ GtkWindow *window);
/* private for gconf notification */
void gedit_plugins_engine_active_plugins_changed
@@ -88,13 +88,13 @@ void gedit_plugins_engine_configure_plugin (GeditPluginsEngine *engine,
GeditPluginInfo *info,
GtkWindow *parent);
-/* plugin activation/deactivation per window, private to GeditWindow */
+/* plugin activation/deactivation per window, private to GtkWindow */
void gedit_plugins_engine_activate_plugins (GeditPluginsEngine *engine,